History
=======

1.1.0 (2020-02-19)
------------------

- Add a way for responses to opt-out from push redirect  
  This allows developers to work around issue #3 
  (Safari won't load some redirects that are being pushed)


1.0.0 (2019-12-03)
------------------

- First release
